You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openoffice.apache.org by pf...@apache.org on 2014/04/29 21:25:24 UTC

svn commit: r1591062 [5/15] - in /openoffice/trunk/main: registry/inc/registry/ registry/tools/ rhino/ ridljar/com/sun/star/lib/util/ ridljar/com/sun/star/uno/ rsc/inc/ rsc/source/parser/ rsc/source/rscpp/ sal/inc/osl/ sal/inc/rtl/ sal/inc/sal/ sal/inc...

Modified: openoffice/trunk/main/sd/source/ui/slidesorter/inc/controller/SlsAnimationFunction.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/slidesorter/inc/controller/SlsAnimationFunction.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/slidesorter/inc/controller/SlsAnimationFunction.hxx (original)
+++ openoffice/trunk/main/sd/source/ui/slidesorter/inc/controller/SlsAnimationFunction.hxx Tue Apr 29 19:25:03 2014
@@ -39,7 +39,7 @@ class SlideSorterView;
 
 namespace sd { namespace slidesorter { namespace controller {
 
-/** A collection of functions that are usefull when creating animations.
+/** A collection of functions that are useful when creating animations.
     They are collected here until a better place is found.
 */
 class AnimationFunction

Modified: openoffice/trunk/main/sd/source/ui/slidesorter/inc/controller/SlsFocusManager.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/slidesorter/inc/controller/SlsFocusManager.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/slidesorter/inc/controller/SlsFocusManager.hxx (original)
+++ openoffice/trunk/main/sd/source/ui/slidesorter/inc/controller/SlsFocusManager.hxx Tue Apr 29 19:25:03 2014
@@ -66,11 +66,11 @@ public:
     /** Move the focus from the currently focused page to one that is
         displayed adjacent to it, either vertically or horizontally.
         @param eDirection
-            Direction in which to move the focus.  Wrap arround is done
+            Direction in which to move the focus.  Wrap around is done
             differently when moving vertically or horizontally.  Vertical
-            wrap arround takes place in the same column, i.e. when you are
+            wrap around takes place in the same column, i.e. when you are
             in the top row and move up you come out in the bottom row in the
-            same column.  Horizontal wrap arround moves to the next
+            same column.  Horizontal wrap around moves to the next
             (FMD_RIGHT) or previous (FMD_LEFT) page.  Moving to the right
             from the last page goes to the first page and vice versa.
             When FMD_NONE is given, the current page index is checked for
@@ -218,7 +218,7 @@ private:
         const bool bScrollToFocus);
 
     /** Call all currently registered listeners that a focus change has
-        happended.  The focus may be hidden or shown or moved from one page
+        happened.  The focus may be hidden or shown or moved from one page
         object to another.
     */
     void NotifyFocusChangeListeners (void) const;

Modified: openoffice/trunk/main/sd/source/ui/slidesorter/inc/controller/SlsPageSelector.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/slidesorter/inc/controller/SlsPageSelector.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/slidesorter/inc/controller/SlsPageSelector.hxx (original)
+++ openoffice/trunk/main/sd/source/ui/slidesorter/inc/controller/SlsPageSelector.hxx Tue Apr 29 19:25:03 2014
@@ -152,7 +152,7 @@ public:
             When <TRUE/> (the default value) then after setting the
             selection update the current page to the first page of the
             selection.
-            When called from withing UpdateCurrentPage() then this flag is
+            When called from within UpdateCurrentPage() then this flag is
             used to prevent a recursion loop.
     */
     void SetPageSelection (

Modified: openoffice/trunk/main/sd/source/ui/slidesorter/inc/model/SlsPageDescriptor.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/slidesorter/inc/model/SlsPageDescriptor.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/slidesorter/inc/model/SlsPageDescriptor.hxx (original)
+++ openoffice/trunk/main/sd/source/ui/slidesorter/inc/model/SlsPageDescriptor.hxx Tue Apr 29 19:25:03 2014
@@ -65,7 +65,7 @@ public:
         @param pPage
             The page pointer can in some situations not be detected from
             rxPage, e.g. after undo of page deletion.  Therefore supply it
-            seperately. 
+            separately. 
         @param nIndex
             This index is displayed in the view as page number.  It is not
             necessaryily the page index (not even when you add or subtract 1

Modified: openoffice/trunk/main/sd/source/ui/slidesorter/inc/view/SlsLayouter.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/slidesorter/inc/view/SlsLayouter.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/slidesorter/inc/view/SlsLayouter.hxx (original)
+++ openoffice/trunk/main/sd/source/ui/slidesorter/inc/view/SlsLayouter.hxx Tue Apr 29 19:25:03 2014
@@ -50,7 +50,7 @@ class InsertPosition;
     2.) Desired and minimal and maximal widths of page objects.
     3.) Minimal and maximal number of columns.
     4.) Vertical and horizontal gaps between objects in adjacent columns.
-    5.) Borders arround every page object.
+    5.) Borders around every page object.
     6.) Vertical and horizontal borders between enclosing page and outer
         page objects.
     From these it calculates various output values:
@@ -99,7 +99,7 @@ public:
         sal_Int32 nTopBorder, sal_Int32 nBottomBorder);
 
     /** Set the interval of valid column counts.  When nMinimalColumnCount
-        <= nMaximalColumnCount is not fullfilled then the call is ignored.
+        <= nMaximalColumnCount is not fulfilled then the call is ignored.
         @param nMinimalColumnCount
             The default value is 1.  The question whether higher values make
             any sense is left to the caller.
@@ -113,7 +113,7 @@ public:
         calculates the output values.  Both given sizes must not be 0 in any
         dimension or the call is ignored.
         @param eOrientation
-            This defines the generaly layout and specifies whether there may
+            This defines the generally layout and specifies whether there may
             be more than one row or more than one column.
         @param rWindowSize
             The size of the window in pixels that the slide sorter is

Modified: openoffice/trunk/main/sd/source/ui/slidesorter/inc/view/SlsPageObjectViewObjectContact.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/slidesorter/inc/view/SlsPageObjectViewObjectContact.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/slidesorter/inc/view/SlsPageObjectViewObjectContact.hxx (original)
+++ openoffice/trunk/main/sd/source/ui/slidesorter/inc/view/SlsPageObjectViewObjectContact.hxx Tue Apr 29 19:25:03 2014
@@ -99,7 +99,7 @@ public:
     model::SharedPageDescriptor GetPageDescriptor (void) const;
 
     /** Return the border widths in the screen coordinate system of the
-        border arround the page object.  The border contains frames for
+        border around the page object.  The border contains frames for
         selection, focus, the page name and number, and the indicator for
         the page transition.
         @param pDevice

Modified: openoffice/trunk/main/sd/source/ui/slidesorter/model/SlsPageEnumeration.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/slidesorter/model/SlsPageEnumeration.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/slidesorter/view/SlsButtonBar.cxx (original)
+++ openoffice/trunk/main/sd/source/ui/slidesorter/view/SlsButtonBar.cxx Tue Apr 29 19:25:03 2014
@@ -138,7 +138,7 @@ namespace {
     };
 
     /** The source mask is essentially multiplied with the given alpha value.
-        The result is writen to the result mask.
+        The result is written to the result mask.
     */
     void AdaptTransparency (AlphaMask& rMask, const AlphaMask& rSourceMask, const double nAlpha)
     {

Modified: openoffice/trunk/main/sd/source/ui/tools/PreviewRenderer.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/tools/PreviewRenderer.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/tools/PreviewRenderer.cxx (original)
+++ openoffice/trunk/main/sd/source/ui/tools/PreviewRenderer.cxx Tue Apr 29 19:25:03 2014
@@ -402,7 +402,7 @@ void PreviewRenderer::PaintFrame (void)
 {
     if (mbHasFrame)
     {
-        // Paint a frame arround the preview.
+        // Paint a frame around the preview.
         Rectangle aPaintRectangle (
             Point(0,0),
             mpPreviewDevice->GetOutputSizePixel());
@@ -517,7 +517,7 @@ Image PreviewRenderer::ScaleBitmap (
         mpPreviewDevice->SetMapMode (aMapMode);
         mpPreviewDevice->SetOutputSize (aFrameSize);
 
-        // Paint a frame arround the preview.
+        // Paint a frame around the preview.
         mpPreviewDevice->SetLineColor (maFrameColor);
         mpPreviewDevice->SetFillColor ();
         mpPreviewDevice->DrawRect (Rectangle(Point(0,0), aFrameSize));

Modified: openoffice/trunk/main/sd/source/ui/view/FormShellManager.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/view/FormShellManager.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/view/FormShellManager.cxx (original)
+++ openoffice/trunk/main/sd/source/ui/view/FormShellManager.cxx Tue Apr 29 19:25:03 2014
@@ -224,7 +224,7 @@ void FormShellManager::UnregisterAtCente
 
 IMPL_LINK(FormShellManager, FormControlActivated, FmFormShell*, EMPTYARG)
 {
-    // The form shell has been actived.  To give it priority in reacting to
+    // The form shell has been activated.  To give it priority in reacting to
     // slot calls the form shell is moved to the top of the object bar shell
     // stack.
     ViewShell* pShell = mrBase.GetMainViewShell().get();

Modified: openoffice/trunk/main/sd/source/ui/view/Outliner.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/view/Outliner.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/view/Outliner.cxx (original)
+++ openoffice/trunk/main/sd/source/ui/view/Outliner.cxx Tue Apr 29 19:25:03 2014
@@ -436,7 +436,7 @@ sal_Bool Outliner::SpellNextDocument (vo
     // found the loop is left through a break.
     // It is the responsibility of the sd outliner object to correctly
     // iterate over all text shapes, i.e. switch between views, wrap
-    // arround at the end of the document, stop when all text shapes
+    // around at the end of the document, stop when all text shapes
     // have been examined exactly once.
     bool bFoundNextSentence = false;
     while ( ! bFoundNextSentence)
@@ -596,7 +596,7 @@ void Outliner::Initialize (bool bDirecti
     }
     else if (bOldDirectionIsForward != mbDirectionIsForward)
     {
-        // Requested iteration direction has changed.  Turn arround the iterator.
+        // Requested iteration direction has changed.  Turn around the iterator.
         maObjectIterator.Reverse();
         if (bIsAtEnd)
         {
@@ -740,7 +740,7 @@ bool Outliner::SearchAndReplaceOnce (voi
 		{
             mpDrawDocument->GetDocSh()->SetWaitCursor (sal_False);
             // The following loop is executed more then once only when a
-            // wrap arround search is done.
+            // wrap around search is done.
             while (true)
             {
                 int nResult = pOutlinerView->StartSearchAndReplace(*mpSearchItem);
@@ -1082,7 +1082,7 @@ void Outliner::EndOfSearch (void)
             ShowEndOfSearchDialog ();
             mbEndOfSearch = sal_True;
         }
-        // Ask the user whether to wrap arround and continue the search or
+        // Ask the user whether to wrap around and continue the search or
         // to terminate.
         else if (meMode==TEXT_CONVERSION || ShowWrapArroundDialog ())
         {
@@ -1101,7 +1101,7 @@ void Outliner::EndOfSearch (void)
         }
         else
         {
-            // No wrap arround.
+            // No wrap around.
             mbEndOfSearch = true;
         }
     }
@@ -1168,7 +1168,7 @@ bool Outliner::ShowWrapArroundDialog (vo
                 ? STR_SAR_WRAP_BACKWARD
                 : STR_SAR_WRAP_BACKWARD_DRAW;
 
-        // Pop up question box that asks the user whether to wrap arround.
+        // Pop up question box that asks the user whether to wrap around.
         // The dialog is made modal with respect to the whole application.
         QueryBox aQuestionBox (
             NULL,
@@ -1265,7 +1265,7 @@ void Outliner::PrepareSearchAndReplace (
         EnterEditMode ();
 
         mpDrawDocument->GetDocSh()->SetWaitCursor( sal_False );
-        // Start seach at the right end of the current object's text
+        // Start search at the right end of the current object's text
         // depending on the search direction.
         OutlinerView* pOutlinerView = mpImpl->GetOutlinerView();
         if (pOutlinerView != NULL)
@@ -1470,7 +1470,7 @@ bool Outliner::HandleFailedSearch (void)
     if (pOutlinerView != NULL && mpSearchItem != NULL)
     {
         // Detect whether there is/may be a prior match.  If there is then
-        // ask the user whether to wrap arround.  Otherwise tell the user
+        // ask the user whether to wrap around.  Otherwise tell the user
         // that there is no match.
         if (HasNoPreviousMatch ())
         {
@@ -1483,7 +1483,7 @@ bool Outliner::HandleFailedSearch (void)
         else
         {
             // No further matches found.  Ask the user whether to wrap
-            // arround and start again.
+            // around and start again.
             bContinueSearch = ShowWrapArroundDialog ();
         }
     }
@@ -1610,7 +1610,7 @@ void Outliner::PrepareConversion (void)
 		EnterEditMode ();
 
 		mpDrawDocument->GetDocSh()->SetWaitCursor( sal_False );
-		// Start seach at the right end of the current object's text
+		// Start search at the right end of the current object's text
 		// depending on the search direction.
 //		mpOutlineView->SetSelection (GetSearchStartPosition ());
 	}
@@ -1684,7 +1684,7 @@ sal_Bool Outliner::ConvertNextDocument()
 	mpDrawDocument->GetDocSh()->SetWaitCursor( sal_False );
 	ClearModifyFlag();
 
-    // for text conversion we automaticly wrap around one
+    // for text conversion we automatically wrap around one
 	// time and stop at the start shape
 	if( mpFirstObj )
 	{

Modified: openoffice/trunk/main/sd/source/ui/view/ToolBarManager.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/view/ToolBarManager.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/view/ToolBarManager.cxx (original)
+++ openoffice/trunk/main/sd/source/ui/view/ToolBarManager.cxx Tue Apr 29 19:25:03 2014
@@ -125,7 +125,7 @@ private:
     list the current list and clears the current list.
 
     Each shell belongs to one group.  Different groups can be modified
-    seperately.
+    separately.
 */
 class ToolBarShellList
 {

Modified: openoffice/trunk/main/sd/source/ui/view/drtxtob.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/view/drtxtob.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/view/drtxtob.cxx (original)
+++ openoffice/trunk/main/sd/source/ui/view/drtxtob.cxx Tue Apr 29 19:25:03 2014
@@ -423,7 +423,7 @@ void TextObjectBar::GetAttrState( SfxIte
 				{
 					rSet.DisableItem( SID_THES );
 				}
-                //! avoid puting the same item as SfxBoolItem at the end of this function
+                //! avoid putting the same item as SfxBoolItem at the end of this function
                 nSlotId = 0;
             }
             break;        

Modified: openoffice/trunk/main/sd/source/ui/view/drviewsh.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/view/drviewsh.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/view/drviewsh.cxx (original)
+++ openoffice/trunk/main/sd/source/ui/view/drviewsh.cxx Tue Apr 29 19:25:03 2014
@@ -86,7 +86,7 @@ void DrawViewShell::MakeVisible(const Re
 	// smaller than the visible area, the user-defined zoom was
 	// changed. This was decided to be a bug for 6.x, thus I developed a
 	// version which instead handles X/Y bigger/smaller and visibility
-	// questions seperately. The new behaviour is triggered with the
+	// questions separately. The new behaviour is triggered with the
 	// bZoomAllowed parameter which for old behaviour should be set to
 	// sal_True. I looked at all uses of MakeVisible() in the application
 	// and found no valid reason for really changing the zoom factor, thus I

Modified: openoffice/trunk/main/sd/source/ui/view/frmview.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/view/frmview.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/view/frmview.cxx (original)
+++ openoffice/trunk/main/sd/source/ui/view/frmview.cxx Tue Apr 29 19:25:03 2014
@@ -561,7 +561,7 @@ void FrameView::WriteUserDataSequence ( 
 //  pValue++;nIndex++;
 
 	aUserData.addValue( sUNO_View_SlidesPerRow, makeAny( (sal_Int16)GetSlidesPerRow() ) );
-/* #107128# Product managment decided to not make this persistent
+/* #107128# Product management decided to not make this persistent
 	aUserData.addValue( sUNO_View_DrawMode, makeAny( (sal_Int32)GetDrawMode() ) );
 	aUserData.addValue( sUNO_View_PreviewDrawMode, makeAny( (sal_Int32)GetPreviewDrawMode() ) );
 */
@@ -799,7 +799,7 @@ void FrameView::ReadUserDataSequence ( c
 					SetSlidesPerRow( (sal_uInt16)nInt16 );
 				}
 			}
-/* #107128# Product managment decided to not make this persistent
+/* #107128# Product management decided to not make this persistent
 			else if (pValue->Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( sUNO_View_DrawMode ) ) )
 			{
 				if( pValue->Value >>= nInt32 )

Modified: openoffice/trunk/main/sd/source/ui/view/sdview.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/view/sdview.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/view/sdview.cxx (original)
+++ openoffice/trunk/main/sd/source/ui/view/sdview.cxx Tue Apr 29 19:25:03 2014
@@ -868,7 +868,7 @@ SdrEndTextEditKind View::SdrEndTextEdit(
 // --------------------------------------------------------------------
 
 /** restores the default text if the given text object is currently in edit mode and
-	no text has been entered already. Is only usefull just before text edit ends. */
+	no text has been entered already. Is only useful just before text edit ends. */
 bool View::RestoreDefaultText( SdrTextObj* pTextObj )
 {
 	bool bRestored = false;

Modified: openoffice/trunk/main/sd/source/ui/view/viewshel.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/view/viewshel.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/view/viewshel.cxx (original)
+++ openoffice/trunk/main/sd/source/ui/view/viewshel.cxx Tue Apr 29 19:25:03 2014
@@ -1114,7 +1114,7 @@ void ViewShell::SetDefTabHRuler( sal_uIn
 
 
 /** Tell the FmFormShell that the view shell is closing.  Give it the
-    oportunity to prevent that.
+    opportunity to prevent that.
 */
 sal_uInt16 ViewShell::PrepareClose (sal_Bool bUI, sal_Bool bForBrowsing)
 {
@@ -1134,7 +1134,7 @@ void ViewShell::UpdatePreview (SdPage*, 
 {
     // Do nothing.  After the actual preview has been removed,
     // OutlineViewShell::UpdatePreview() is the place where something
-    // usefull is still done.
+    // useful is still done.
 }
 
 ::svl::IUndoManager* ViewShell::ImpGetUndoManager (void) const

Modified: openoffice/trunk/main/sdext/source/pdfimport/inc/pdfparse.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sdext/source/pdfimport/inc/pdfparse.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sdext/source/pdfimport/inc/pdfparse.hxx (original)
+++ openoffice/trunk/main/sdext/source/pdfimport/inc/pdfparse.hxx Tue Apr 29 19:25:03 2014
@@ -198,7 +198,7 @@ struct PDFDict : public PDFContainer
     // removes a name/value pair from the dict
     void eraseValue( const rtl::OString& rName );
     // builds new map as of sub elements
-    // returns NULL if successfull, else the first offending element
+    // returns NULL if successful, else the first offending element
     PDFEntry* buildMap();
 };
 

Modified: openoffice/trunk/main/sdext/source/presenter/PresenterFrameworkObserver.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sdext/source/presenter/PresenterFrameworkObserver.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sdext/source/presenter/PresenterFrameworkObserver.hxx (original)
+++ openoffice/trunk/main/sdext/source/presenter/PresenterFrameworkObserver.hxx Tue Apr 29 19:25:03 2014
@@ -54,7 +54,7 @@ public:
 
     /** Register an action callback to be run when the specified resource is
         activated.  The action may be called synchronously when the resource
-        is already active or asynchronously when the resource is actived in
+        is already active or asynchronously when the resource is activated in
         the future.
         @param rxController
             The controller gives access to the drawing framework.

Modified: openoffice/trunk/main/sdext/source/presenter/PresenterScreen.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sdext/source/presenter/PresenterScreen.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sdext/source/presenter/PresenterScreen.cxx (original)
+++ openoffice/trunk/main/sdext/source/presenter/PresenterScreen.cxx Tue Apr 29 19:25:03 2014
@@ -464,7 +464,7 @@ void PresenterScreen::InitializePresente
                 // own full screen window that is controlled by the same
                 // configuration controller as the Impress document from
                 // which the presentation was started.  Therefore the main
-                // pane is actived additionally to the already existing
+                // pane is activated additionally to the already existing
                 // panes and does not replace them.
 				xCC->requestResourceActivation(
 					xMainPaneId,

Modified: openoffice/trunk/main/sdext/source/presenter/PresenterSlidePreview.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sdext/source/presenter/PresenterSlidePreview.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sdext/source/presenter/PresenterSlidePreview.cxx (original)
+++ openoffice/trunk/main/sdext/source/presenter/PresenterSlidePreview.cxx Tue Apr 29 19:25:03 2014
@@ -43,7 +43,7 @@ using ::rtl::OUString;
 
 namespace
 {
-    // Use a super sample factor greater than 1 to achive a poor mans
+    // Use a super sample factor greater than 1 to achieve a poor mans
     // antialiasing effect for slide previews.
     const sal_Int16 gnSuperSampleFactor = 2;
 }

Modified: openoffice/trunk/main/sdext/source/presenter/PresenterSlideShowView.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sdext/source/presenter/PresenterSlideShowView.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sdext/source/presenter/PresenterSlideShowView.cxx (original)
+++ openoffice/trunk/main/sdext/source/presenter/PresenterSlideShowView.cxx Tue Apr 29 19:25:03 2014
@@ -167,7 +167,7 @@ void PresenterSlideShowView::LateInit (v
     {
         Reference<presentation::XSlideShowView> xView (this);
         mxSlideShow->addView(xView);
-        // Prevent embeded sounds being played twice at the same time by
+        // Prevent embedded sounds being played twice at the same time by
         // disabling sound for the new slide show view.
         beans::PropertyValue aProperty;
         aProperty.Name = A2S("IsSoundEnabled");

Modified: openoffice/trunk/main/sdext/source/presenter/PresenterSlideSorter.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sdext/source/presenter/PresenterSlideSorter.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sdext/source/presenter/PresenterSlideSorter.cxx (original)
+++ openoffice/trunk/main/sdext/source/presenter/PresenterSlideSorter.cxx Tue Apr 29 19:25:03 2014
@@ -1294,7 +1294,7 @@ void PresenterSlideSorter::Layout::Updat
     // Determine column count, preview width, and horizontal gap (borders
     // are half the gap).  Try to use the preferred values.  Try more to
     // stay in the valid intervalls.  This last constraint may be not
-    // fullfilled in some cases.
+    // fulfilled in some cases.
     const double nElementWidth = nWidth / gnPreferredColumnCount;
     if (nElementWidth < gnMinimalPreviewWidth + gnMinimalHorizontalPreviewGap)
     {

Modified: openoffice/trunk/main/sdext/source/presenter/PresenterViewFactory.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sdext/source/presenter/PresenterViewFactory.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sdext/source/presenter/PresenterViewFactory.hxx (original)
+++ openoffice/trunk/main/sdext/source/presenter/PresenterViewFactory.hxx Tue Apr 29 19:25:03 2014
@@ -62,7 +62,7 @@ public:
     virtual void DeactivatePresenterView (void);
 
     /** Called before the view is disposed.  This gives the view the
-        oportunity to trigger actions that may lead to (synchronous)
+        opportunity to trigger actions that may lead to (synchronous)
         callbacks that do not result in DisposedExceptions.
     */
     virtual void ReleaseView (void);

Modified: openoffice/trunk/main/setup_native/scripts/admin.pl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/setup_native/scripts/admin.pl?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/setup_native/scripts/admin.pl (original)
+++ openoffice/trunk/main/setup_native/scripts/admin.pl Tue Apr 29 19:25:03 2014
@@ -143,7 +143,7 @@ sub controlparameter
 
 #############################################################################
 # The program msidb.exe can be located next to the Perl program. Then it is
-# not neccessary to find it in the PATH variable. 
+# not necessary to find it in the PATH variable. 
 #############################################################################
 
 sub check_local_msidb
@@ -263,7 +263,7 @@ sub check_system_path
 }
 
 ##########################################################################
-# Searching a file in a list of pathes
+# Searching a file in a list of paths
 ##########################################################################
 
 sub get_sourcepath_from_filename_and_includepath
@@ -843,7 +843,7 @@ sub create_directory_structure
 	
 	foreach $dir (@startparents) { create_directory_tree($dir, \%fullpathhash, $targetdir, $dirhash); }
 
-	# Also adding the pathes of the startparents
+	# Also adding the paths of the startparents
 	foreach $dir (@startparents)
 	{
 		if ( ! exists($fullpathhash{$dir}) ) { $fullpathhash{$dir} = $targetdir; }

Modified: openoffice/trunk/main/setup_native/scripts/deregister_extensions
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/setup_native/scripts/deregister_extensions?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/setup_native/scripts/deregister_extensions (original)
+++ openoffice/trunk/main/setup_native/scripts/deregister_extensions Tue Apr 29 19:25:03 2014
@@ -47,7 +47,7 @@ help()
 
 # if [ $UID -ne 0 ]
 # then
-#     printf "\nThis script is for installation only wiht administrative rights only\n"
+#     printf "\nThis script is for installation only with administrative rights only\n"
 #     help
 #     exit 2
 # fi

Modified: openoffice/trunk/main/setup_native/scripts/register_extensions
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/setup_native/scripts/register_extensions?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/setup_native/scripts/register_extensions (original)
+++ openoffice/trunk/main/setup_native/scripts/register_extensions Tue Apr 29 19:25:03 2014
@@ -49,7 +49,7 @@ help()
 
 # if [ $UID -ne 0 ]
 # then
-#     printf "\nThis script is for installation only wiht administrative rights only\n"
+#     printf "\nThis script is for installation only with administrative rights only\n"
 #     help
 #     exit 2
 # fi

Modified: openoffice/trunk/main/setup_native/source/opensolaris/bundledextensions/README
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/setup_native/source/opensolaris/bundledextensions/README?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/setup_native/source/opensolaris/bundledextensions/README (original)
+++ openoffice/trunk/main/setup_native/source/opensolaris/bundledextensions/README Tue Apr 29 19:25:03 2014
@@ -50,7 +50,7 @@ already been installed with unopkg. This
 extensions whenever the service is restarted.
 
 When a new version of OOo becomes available, then the respective OOo package
-containes a new version of 'installed'. That is, it contains a version string,
+contains a new version of 'installed'. That is, it contains a version string,
 such as 3.2.0. The sole reason for that string is, to change the content of this
 file in every release. Otherwise IPS would not replace the installed version of
 'installed' with the one contained in the package. 

Modified: openoffice/trunk/main/setup_native/source/opensolaris/bundledextensions/svc-ooo_bundled_extensions
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/setup_native/source/opensolaris/bundledextensions/svc-ooo_bundled_extensions?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/setup_native/source/opensolaris/bundledextensions/svc-ooo_bundled_extensions (original)
+++ openoffice/trunk/main/setup_native/source/opensolaris/bundledextensions/svc-ooo_bundled_extensions Tue Apr 29 19:25:03 2014
@@ -107,7 +107,7 @@ case "$1" in
 #     done 
 
 #     #Write the new list to the file "installed". It now has all names
-#     #remove which refered to previously removed extensions (removed
+#     #remove which referred to previously removed extensions (removed
 #     #from .../share/extension/install)
 #     if  [ "$REMOVED" ]; then
 # 	#remove the last empty line

Modified: openoffice/trunk/main/setup_native/source/win32/customactions/patch/swappatchfiles.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/setup_native/source/win32/customactions/patch/swappatchfiles.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/setup_native/source/win32/customactions/patch/swappatchfiles.cxx (original)
+++ openoffice/trunk/main/setup_native/source/win32/customactions/patch/swappatchfiles.cxx Tue Apr 29 19:25:03 2014
@@ -87,7 +87,7 @@ static std::_tstring GetMsiProperty( MSI
 	return	result;
 }
 
-// The provided GUID must be without surounding '{}'
+// The provided GUID must be without surrounding '{}'
 static std::_tstring GetGuidPart(const std::_tstring& guid, int index)
 {
 	assert((guid.length() == 36) && "No GUID or wrong format!"); 

Modified: openoffice/trunk/main/setup_native/source/win32/customactions/reg4msdoc/registrar.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/setup_native/source/win32/customactions/reg4msdoc/registrar.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/setup_native/source/win32/customactions/reg4msdoc/registrar.cxx (original)
+++ openoffice/trunk/main/setup_native/source/win32/customactions/reg4msdoc/registrar.cxx Tue Apr 29 19:25:03 2014
@@ -331,7 +331,7 @@ bool Registrar::QueryPreselectMsPowerPoi
       HKCR\.htm\OpenWithList\App Friendly Name\shell\edit\command
       But the reality shows that this works only 
       with Internet Explorer 5.x 
-      Internet Explorer 6.0 wants the follwoing 
+      Internet Explorer 6.0 wants the following 
       entries:
       HKCR\.htm\OpenWithList\App.exe
       HKCR\Applications\App.ex\shell\edit\command      

Modified: openoffice/trunk/main/setup_native/source/win32/customactions/reg4msdoc/userregistrar.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/setup_native/source/win32/customactions/reg4msdoc/userregistrar.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/setup_native/source/win32/customactions/reg4msdoc/userregistrar.cxx (original)
+++ openoffice/trunk/main/setup_native/source/win32/customactions/reg4msdoc/userregistrar.cxx Tue Apr 29 19:25:03 2014
@@ -148,7 +148,7 @@ RegistryKey UserRegistrar::GetRootKeyFor
 void UserRegistrar::DeleteHtmFileAssociationKeys() const
 {
     // Later delete the created keys if they are empty and have not changed meanwhile.
-    // Remeber: if we create a new registry key in the user part of the
+    // Remember: if we create a new registry key in the user part of the
     // registry, changes to that key via the merged key HKEY_CLASSES_ROOT
     // go into the user branch HKEY_CURRENT_USER and are not visible for other users. 
     // so we must carefully detect if the keys have not changed in order to prevent accidentally

Modified: openoffice/trunk/main/setup_native/source/win32/customactions/shellextensions/completeinstallpath.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/setup_native/source/win32/customactions/shellextensions/completeinstallpath.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/setup_native/source/win32/customactions/shellextensions/completeinstallpath.cxx (original)
+++ openoffice/trunk/main/setup_native/source/win32/customactions/shellextensions/completeinstallpath.cxx Tue Apr 29 19:25:03 2014
@@ -100,7 +100,7 @@ extern "C" UINT __stdcall CompleteInstal
 	}
 	
 	// If the path INSTALLLOCATION does not end with this string, INSTALLLOCATION is maybe
-	// transfered from an OOo 3.0, OOo 3.1 and OOo 3.2 and need to be changed therefore.
+	// transferred from an OOo 3.0, OOo 3.1 and OOo 3.2 and need to be changed therefore.
 
 	if ( pathCompletionRequired )
 	{

Modified: openoffice/trunk/main/setup_native/source/win32/customactions/shellextensions/upgrade.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/setup_native/source/win32/customactions/shellextensions/upgrade.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/setup_native/source/win32/customactions/shellextensions/upgrade.cxx (original)
+++ openoffice/trunk/main/setup_native/source/win32/customactions/shellextensions/upgrade.cxx Tue Apr 29 19:25:03 2014
@@ -46,7 +46,7 @@ using namespace std;
 
 namespace 
 {
-    // The provided GUID must be without surounding '{}'
+    // The provided GUID must be without surrounding '{}'
     string GetGuidPart(const string& guid, int index)
     {
         assert((guid.length() == 36) && "No GUID or wrong format!"); 

Modified: openoffice/trunk/main/sfx2/inc/sfx2/docmacromode.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/inc/sfx2/docmacromode.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/inc/sfx2/docmacromode.hxx (original)
+++ openoffice/trunk/main/sfx2/inc/sfx2/docmacromode.hxx Tue Apr 29 19:25:03 2014
@@ -107,7 +107,7 @@ namespace sfx2
         virtual ::rtl::OUString
                     getDocumentLocation() const = 0;
 
-        /** returns a zip-storage based on the last commited version of the document,
+        /** returns a zip-storage based on the last committed version of the document,
             for readonly access
 
             The storage is intended to be used for signing. An implementation is

Modified: openoffice/trunk/main/sfx2/inc/sfx2/sfxbasemodel.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/inc/sfx2/sfxbasemodel.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/inc/sfx2/sfxbasemodel.hxx (original)
+++ openoffice/trunk/main/sfx2/inc/sfx2/sfxbasemodel.hxx Tue Apr 29 19:25:03 2014
@@ -386,7 +386,7 @@ public:
 
 	/**___________________________________________________________________________________________________
 		@short		get implementation id
-		@descr      This ID is neccessary for UNO-caching. If there no ID, cache is disabled.
+		@descr      This ID is necessary for UNO-caching. If there no ID, cache is disabled.
 					Another way, cache is enabled.
 
 		@seealso	XTypeProvider

Modified: openoffice/trunk/main/sfx2/inc/sfx2/titledockwin.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/inc/sfx2/titledockwin.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/inc/sfx2/titledockwin.hxx (original)
+++ openoffice/trunk/main/sfx2/inc/sfx2/titledockwin.hxx Tue Apr 29 19:25:03 2014
@@ -145,7 +145,7 @@ namespace sfx2
 
         Link                m_aEndDockingHdl;
 
-        /** The border that is painted arround the inner window.  The bevel
+        /** The border that is painted around the inner window.  The bevel
             shadow lines are part of the border, so where the border is 0 no
             such line is painted.
         */

Modified: openoffice/trunk/main/sfx2/qa/complex/sfx2/DocumentProperties.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/qa/complex/sfx2/DocumentProperties.java?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/qa/complex/sfx2/DocumentProperties.java (original)
+++ openoffice/trunk/main/sfx2/qa/complex/sfx2/DocumentProperties.java Tue Apr 29 19:25:03 2014
@@ -277,7 +277,7 @@ public class DocumentProperties
             xDP.setModificationDate(dt);
             assertTrue("setModificationDate",
                 dt.Year == xDP.getModificationDate().Year);
-            str = "i didnt do it";
+            str = "i didn't do it";
             xDP.setPrintedBy(str);
             assertTrue("setPrintedBy", str.equals(xDP.getPrintedBy()));
             dt.Year = 2024;
@@ -338,7 +338,7 @@ public class DocumentProperties
             // differently some day...
             boolean b = true;
             double d = 3.1415;
-            // note that Time is only supported for backward compatibilty!
+            // note that Time is only supported for backward compatibility!
             Time t = new Time();
             t.Hours = 1;
             t.Minutes = 16;

Modified: openoffice/trunk/main/sfx2/source/appl/appinit.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/appl/appinit.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/appl/appinit.cxx (original)
+++ openoffice/trunk/main/sfx2/source/appl/appinit.cxx Tue Apr 29 19:25:03 2014
@@ -172,8 +172,8 @@ void SAL_CALL SfxTerminateListener_Impl:
 
 Sequence< ::rtl::OUString > SAL_CALL SfxTerminateListener_Impl::getSupportedServiceNames() throw (RuntimeException)
 {
-    // Note: That service  does not realy exists .-)
-    // But this implementation is not thought to be registered realy within our service.rdb.
+    // Note: That service  does not really exists .-)
+    // But this implementation is not thought to be registered really within our service.rdb.
     // At least we need the implementation name only to identify these service at the global desktop instance.
     // The desktop must know, which listener will terminate the SfxApplication in real !
     // It must call this special listener as last one ... otherwise we shutdown the SfxApplication BEFORE other listener

Modified: openoffice/trunk/main/sfx2/source/appl/appopen.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/appl/appopen.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/appl/appopen.cxx (original)
+++ openoffice/trunk/main/sfx2/source/appl/appopen.cxx Tue Apr 29 19:25:03 2014
@@ -268,7 +268,7 @@ private:
     {
         // check the encryption data
         // if the data correct is the stream will be opened successfuly
-        // and immediatelly closed
+        // and immediately closed
         ::comphelper::OStorageHelper::SetCommonStorageEncryptionData( mxStorage, rEncryptionData );
 
         mxStorage->openStreamElement(
@@ -552,7 +552,7 @@ void SfxApplication::NewDocDirectExec_Im
     aReq.AppendItem( SfxFrameItem( SID_DOCFRAME, GetFrame() ) );
     aReq.AppendItem( SfxStringItem( SID_TARGETNAME, String::CreateFromAscii( "_default" ) ) );
 
-    // TODO/LATER: Should the other arguments be transfered as well?
+    // TODO/LATER: Should the other arguments be transferred as well?
     SFX_REQUEST_ARG( rReq, pDefaultPathItem, SfxStringItem, SID_DEFAULTFILEPATH, sal_False);
     if ( pDefaultPathItem )
         aReq.AppendItem( *pDefaultPathItem );
@@ -762,7 +762,7 @@ void SfxApplication::OpenDocExec_Impl( S
         		rReq.AppendItem( SfxBoolItem( SID_TEMPLATE, sal_False ) );
 
             // This helper wraps an existing (or may new created InteractionHandler)
-            // intercept all incoming interactions and provide usefull informations
+            // intercept all incoming interactions and provide useful informations
             // later if the following transaction was finished.
 
             ::framework::PreventDuplicateInteraction*                 pHandler       = new ::framework::PreventDuplicateInteraction(::comphelper::getProcessServiceFactory());
@@ -1217,7 +1217,7 @@ void SfxApplication::OpenDocExec_Impl( S
     Reference < XController > xController;
 //    if ( ( !bIsBlankTarget && pFrame ) || pLinkItem || !rReq.IsSynchronCall() )
 //    {
-        // if a frame is given, it must be used for the starting point of the targetting mechanism
+        // if a frame is given, it must be used for the starting point of the targeting mechanism
         // this code is also used if asynchronous loading is possible, because loadComponent always is synchron
         if ( !xTargetFrame.is() )
         {
@@ -1252,7 +1252,7 @@ void SfxApplication::OpenDocExec_Impl( S
         if( bHidden || pLinkItem || rReq.IsSynchronCall() )
         {
             // if loading must be done synchron, we must wait for completion to get a return value
-            // find frame by myself; I must konw the exact frame to get the controller for the return value from it
+            // find frame by myself; I must know the exact frame to get the controller for the return value from it
             //if( aTarget.getLength() )
             //    xTargetFrame = xTargetFrame->findFrame( aTarget, FrameSearchFlag::ALL );
             Reference < XComponent > xComp;

Modified: openoffice/trunk/main/sfx2/source/appl/appquit.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/appl/appquit.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/appl/appquit.cxx (original)
+++ openoffice/trunk/main/sfx2/source/appl/appquit.cxx Tue Apr 29 19:25:03 2014
@@ -156,7 +156,7 @@ void SfxApplication::Deinitialize()
     //TODO/CLEANTUP
     //ReleaseArgs could be used instead!
 /* This leak is intended !
-   Otherwise the TestTool cant use .uno:QuitApp ...
+   Otherwise the TestTool can't use .uno:QuitApp ...
    because every destructed ItemSet work's on an already
    released pool pointer .-)
 

Modified: openoffice/trunk/main/sfx2/source/appl/appserv.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/appl/appserv.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/appl/appserv.cxx (original)
+++ openoffice/trunk/main/sfx2/source/appl/appserv.cxx Tue Apr 29 19:25:03 2014
@@ -197,7 +197,7 @@ void SfxApplication::MiscExec_Impl( SfxR
             {
                 /* Dont save the request for closing the application and try it later
                    again. This is an UI bound functionality ... and the user will  try it again
-                   if the dialog is closed. But we shouldnt close the application automaticly
+                   if the dialog is closed. But we shouldn't close the application automatically
                    if this dialog is closed by the user ...
                    So we ignore this request now and wait for a new user decision.
                 */

Modified: openoffice/trunk/main/sfx2/source/appl/childwin.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/appl/childwin.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/appl/childwin.cxx (original)
+++ openoffice/trunk/main/sfx2/source/appl/childwin.cxx Tue Apr 29 19:25:03 2014
@@ -827,7 +827,7 @@ void SfxChildWindow::SetFrame( const ::c
                 pImp->xListener = ::com::sun::star::uno::Reference< ::com::sun::star::lang::XEventListener >( new DisposeListener( this, pImp ) );
 
         // Set new frame in data container
-        // and build new listener connection, if neccessary.
+        // and build new listener connection, if necessary.
         pImp->xFrame = rFrame;
         if( pImp->xFrame.is() )
             pImp->xFrame->addEventListener( pImp->xListener );

Modified: openoffice/trunk/main/sfx2/source/bastyp/bitset.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/bastyp/bitset.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/bastyp/bitset.cxx (original)
+++ openoffice/trunk/main/sfx2/source/bastyp/bitset.cxx Tue Apr 29 19:25:03 2014
@@ -84,7 +84,7 @@ BitSet BitSet::operator<<( sal_uInt16 nO
 
 //--------------------------------------------------------------------
 
-// substracts nOffset from each bit-value in the set
+// subtracts nOffset from each bit-value in the set
 
 BitSet BitSet::operator>>( sal_uInt16 ) const
 {

Modified: openoffice/trunk/main/sfx2/source/bastyp/fltlst.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/bastyp/fltlst.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/bastyp/fltlst.cxx (original)
+++ openoffice/trunk/main/sfx2/source/bastyp/fltlst.cxx Tue Apr 29 19:25:03 2014
@@ -50,7 +50,7 @@ using namespace ::com::sun::star;
 
 /*-************************************************************************************************************//**
     @short          ctor
-    @descr          These initialize an instance of a SfxFilterListener class. Created object listen automaticly
+    @descr          These initialize an instance of a SfxFilterListener class. Created object listen automatically
                     on right FilterFactory-Service for all changes and synchronize right SfxFilterContainer with
                     corresponding framework-cache.
                     We use given "sFactory" value to decide which query must be used to fill "pContainer" with new values.

Modified: openoffice/trunk/main/sfx2/source/bastyp/sfxhtml.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/bastyp/sfxhtml.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/bastyp/sfxhtml.cxx (original)
+++ openoffice/trunk/main/sfx2/source/bastyp/sfxhtml.cxx Tue Apr 29 19:25:03 2014
@@ -80,7 +80,7 @@ SfxHTMLParser::SfxHTMLParser( SvStream& 
 	DBG_ASSERT( !IsSwitchToUCS2(),
 				"SfxHTMLParser::SfxHTMLParser: Switch to UCS2?" );
 
-	// Altough the real default encoding is ISO8859-1, we use MS-1252
+	// Although the real default encoding is ISO8859-1, we use MS-1252
 	// als default encoding.
 	SetSrcEncoding( GetExtendedCompatibilityTextEncoding(  RTL_TEXTENCODING_ISO_8859_1 ) );
 

Modified: openoffice/trunk/main/sfx2/source/config/evntconf.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/config/evntconf.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/config/evntconf.cxx (original)
+++ openoffice/trunk/main/sfx2/source/config/evntconf.cxx Tue Apr 29 19:25:03 2014
@@ -261,7 +261,7 @@ void PropagateEvent_Impl( SfxObjectShell
             { DBG_ERRORFILE( "PropagateEvents_Impl: caught NoSuchElementException" ); }
         }
         else {
-            DBG_WARNING( "PropagateEvents_Impl: Got unkown event" );
+            DBG_WARNING( "PropagateEvents_Impl: Got unknown event" );
         }
     }
 }

Modified: openoffice/trunk/main/sfx2/source/dialog/dockwin.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/dialog/dockwin.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/dialog/dockwin.cxx (original)
+++ openoffice/trunk/main/sfx2/source/dialog/dockwin.cxx Tue Apr 29 19:25:03 2014
@@ -1413,7 +1413,7 @@ SfxChildAlignment SfxDockingWindow::Calc
         aSmallDockingRect.SetPos(rPos);
         Rectangle aIntersectRect = aInRect.GetIntersection( aSmallDockingRect );
         if ( aIntersectRect == aSmallDockingRect )
-			// docking rectangle completely inside (shrinked) inner area -> floating mode
+			// docking rectangle completely inside (shrunk) inner area -> floating mode
             bBecomesFloating = sal_True;
 	}
 

Modified: openoffice/trunk/main/sfx2/source/dialog/filtergrouping.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/dialog/filtergrouping.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/dialog/filtergrouping.cxx (original)
+++ openoffice/trunk/main/sfx2/source/dialog/filtergrouping.cxx Tue Apr 29 19:25:03 2014
@@ -1233,7 +1233,7 @@ namespace sfx2
 			::std::list< FilterGroup >::iterator pIter = aAllFilters.begin();
 			++pIter;
 			::std::for_each(
-				pIter, // first filter group was handled seperately, see above
+				pIter, // first filter group was handled separately, see above
 				aAllFilters.end(),
 				AppendFilterGroup( _rxFilterManager, &_rFileDlgImpl ) );
 		}

Modified: openoffice/trunk/main/sfx2/source/doc/Metadatable.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/doc/Metadatable.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/doc/Metadatable.cxx (original)
+++ openoffice/trunk/main/sfx2/source/doc/Metadatable.cxx Tue Apr 29 19:25:03 2014
@@ -83,7 +83,7 @@
     These serve only to track the position in an XML ID list in a document
     registry, so that future actions can insert objects at the right position.
     Unfortunately, inserting dummy objects seems to be necessary:
-    <ul><li>it is not sufficent to just remember the saved id, because then
+    <ul><li>it is not sufficient to just remember the saved id, because then
             the relative priorities might change when executing the undo</li>
         <li>it is not sufficient to record the position as an integer, because
             if we delete a text node and then undo, the node will be copied(!),

Modified: openoffice/trunk/main/sfx2/source/doc/docfile.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/doc/docfile.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/doc/docfile.cxx (original)
+++ openoffice/trunk/main/sfx2/source/doc/docfile.cxx Tue Apr 29 19:25:03 2014
@@ -2533,7 +2533,7 @@ void SfxMedium::UseInteractionHandler( s
 ::com::sun::star::uno::Reference< ::com::sun::star::task::XInteractionHandler >
 SfxMedium::GetInteractionHandler()
 {
-    // if interaction isnt allowed explicitly ... return empty reference!
+    // if interaction isn't allowed explicitly ... return empty reference!
     if ( !pImp->bUseInteractionHandler )
         return ::com::sun::star::uno::Reference< ::com::sun::star::task::XInteractionHandler >();
 
@@ -2546,7 +2546,7 @@ SfxMedium::GetInteractionHandler()
             return xHandler;
     }
 
-    // if default interaction isnt allowed explicitly ... return empty reference!
+    // if default interaction isn't allowed explicitly ... return empty reference!
     if ( !pImp->bAllowDefaultIntHdl )
         return ::com::sun::star::uno::Reference< ::com::sun::star::task::XInteractionHandler >();
 
@@ -3405,7 +3405,7 @@ sal_Bool SfxMedium::IsReadOnly()
 {
     sal_Bool bReadOnly = sal_False;
 
-    // a) ReadOnly filter cant produce read/write contents!
+    // a) ReadOnly filter can't produce read/write contents!
     bReadOnly = (
                     (pFilter                                                                         ) &&
                     ((pFilter->GetFilterFlags() & SFX_FILTER_OPENREADONLY) == SFX_FILTER_OPENREADONLY)

Modified: openoffice/trunk/main/sfx2/source/doc/doctempl.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/doc/doctempl.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/doc/doctempl.cxx (original)
+++ openoffice/trunk/main/sfx2/source/doc/doctempl.cxx Tue Apr 29 19:25:03 2014
@@ -134,7 +134,7 @@ class DocTempl_EntryData_Impl
 {
     RegionData_Impl*    mpParent;
 
-    // the following member must be SfxObjectShellLock since it controlls that SfxObjectShell lifetime by design
+    // the following member must be SfxObjectShellLock since it controls that SfxObjectShell lifetime by design
     // and users of this class expect it to be so.
     SfxObjectShellLock  mxObjShell;
 

Modified: openoffice/trunk/main/sfx2/source/doc/docvor.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/doc/docvor.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/doc/docvor.cxx (original)
+++ openoffice/trunk/main/sfx2/source/doc/docvor.cxx Tue Apr 29 19:25:03 2014
@@ -420,7 +420,7 @@ ImpPath_Impl::ImpPath_Impl( const ImpPat
 
 	Implementierungsklasse; Darstellung einer Position in der Outline-
 	Listbox als sal_uInt16-Array; dieses beschreibt die Position jeweil
-	als relative Postion zum "ubergeordneten Eintrag
+	als relative Position zum "ubergeordneten Eintrag
 
 */
 class Path

Modified: openoffice/trunk/main/sfx2/source/doc/graphhelp.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/doc/graphhelp.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/doc/graphhelp.cxx (original)
+++ openoffice/trunk/main/sfx2/source/doc/graphhelp.cxx Tue Apr 29 19:25:03 2014
@@ -356,7 +356,7 @@ sal_Bool GraphicHelper::createThumb_Impl
 		const_cast< GDIMetaFile& >( rMtf ).WindStart();
 		const_cast< GDIMetaFile& >( rMtf ).Play( &aVDev, aBackPosPix, aDrawSize );
 		
-		// draw overlay if neccessary
+		// draw overlay if necessary
 		if ( pOverlay )
 			aVDev.DrawBitmapEx( aOverlayRect.TopLeft(), aOverlayRect.GetSize(), *pOverlay );
 		

Modified: openoffice/trunk/main/sfx2/source/doc/objcont.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/doc/objcont.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/doc/objcont.cxx (original)
+++ openoffice/trunk/main/sfx2/source/doc/objcont.cxx Tue Apr 29 19:25:03 2014
@@ -247,7 +247,7 @@ void SfxObjectShell::UpdateTime_Impl(
     util::Duration editDuration(sal_False, 0, 0, 0,
             secs/3600, (secs%3600)/60, secs%60, 0);
 
-	// Initialize some local member! Its neccessary for wollow operations!
+	// Initialize some local member! Its necessary for wollow operations!
 	DateTime	aNow					;	// Date and time at current moment
 	Time		n24Time		(24,0,0,0)	;	// Time-value for 24 hours - see follow calculation
 	sal_uIntPtr		nDays		= 0			;	// Count of days between now and last editing

Modified: openoffice/trunk/main/sfx2/source/doc/objserv.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/doc/objserv.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/doc/objserv.cxx (original)
+++ openoffice/trunk/main/sfx2/source/doc/objserv.cxx Tue Apr 29 19:25:03 2014
@@ -658,8 +658,8 @@ void SfxObjectShell::ExecFile_Impl(SfxRe
 				GetMedium()->SetUpdatePickList( sal_True );
 
                 // TODO: in future it must be done in followind way
-				// if document is opened from GUI it is immediatelly appeares in the picklist
-				// if the document is a new one then it appeares in the picklist immediatelly
+				// if document is opened from GUI it is immediately appeares in the picklist
+				// if the document is a new one then it appeares in the picklist immediately
 				// after SaveAs operation triggered from GUI
 			}
 			catch( task::ErrorCodeIOException& aErrorEx )
@@ -1002,7 +1002,7 @@ void SfxObjectShell::GetState_Impl(SfxIt
 			{
     			/*
 
-    			 search for filter cant work correctly ...
+    			 search for filter can't work correctly ...
     			 Because it's not clear, which export filter for which office module
                  must be searched. On the other side it can be very expensive doing so.
                  The best solution would be: on installation time we should know if pdf feature

Modified: openoffice/trunk/main/sfx2/source/doc/objstor.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/doc/objstor.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/doc/objuno.cxx (original)
+++ openoffice/trunk/main/sfx2/source/doc/objuno.cxx Tue Apr 29 19:25:03 2014
@@ -692,7 +692,7 @@ void SAL_CALL SfxDocumentInfoObject::rem
         ::rtl::OUStringBuffer sMsg(256);
         sMsg.appendAscii("The property \""                                                    );
         sMsg.append     (sName                                                                );
-        sMsg.appendAscii("\" cant be removed. Its a fix property of the DocumentInfo service.");
+        sMsg.appendAscii("\" can't be removed. Its a fix property of the DocumentInfo service.");
 
         throw ::com::sun::star::beans::NotRemoveableException(
                 sMsg.makeStringAndClear(),
@@ -721,7 +721,7 @@ void SAL_CALL  SfxDocumentInfoObject::se
         lang::WrappedTargetException)
 {
     // Attention: Only fix properties should be provided by this method.
-    // Dynamic properties has no handle in real ... because it cant be used inside multithreaded environments :-)
+    // Dynamic properties has no handle in real ... because it can't be used inside multithreaded environments :-)
 
     ::osl::ClearableMutexGuard aGuard( _pImp->_aMutex );
 
@@ -937,7 +937,7 @@ void SAL_CALL  SfxDocumentInfoObject::se
         lang::WrappedTargetException)
 {
     // Attention: Only fix properties should be provided by this method.
-    // Dynamic properties has no handle in real ... because it cant be used inside multithreaded environments :-)
+    // Dynamic properties has no handle in real ... because it can't be used inside multithreaded environments :-)
 
     ::osl::MutexGuard aGuard( _pImp->_aMutex );
 	::com::sun::star::uno::Any aValue;

Modified: openoffice/trunk/main/sfx2/source/doc/objxtor.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/doc/objxtor.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/doc/objxtor.cxx (original)
+++ openoffice/trunk/main/sfx2/source/doc/objxtor.cxx Tue Apr 29 19:25:03 2014
@@ -497,7 +497,7 @@ SfxObjectShell* SfxObjectShell::GetFirst
 {
 	SfxObjectShellArr_Impl &rDocs = SFX_APP()->GetObjectShells_Impl();
 
-	// seach for a SfxDocument of the specified type
+	// search for a SfxDocument of the specified type
 	for ( sal_uInt16 nPos = 0; nPos < rDocs.Count(); ++nPos )
 	{
 		SfxObjectShell* pSh = rDocs.GetObject( nPos );

Modified: openoffice/trunk/main/sfx2/source/doc/printhelper.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/doc/printhelper.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/doc/sfxbasemodel.cxx (original)
+++ openoffice/trunk/main/sfx2/source/doc/sfxbasemodel.cxx Tue Apr 29 19:25:03 2014
@@ -510,7 +510,7 @@ SfxSaveGuard::~SfxSaveGuard()
     // storing at the same time. Further m_bSuicide was set to sal_True only if close(sal_True) was called.
     // So the owner ship was delegated to the place where a veto exception was thrown.
     // Now we have to call close() again and delegate the owner ship to the next one, which
-    // cant accept that. Close(sal_False) cant work in this case. Because then the document will may be never closed ...
+    // can't accept that. Close(sal_False) can't work in this case. Because then the document will may be never closed ...
 
     if ( m_pData->m_bSuicide )
     {
@@ -1431,7 +1431,7 @@ void SAL_CALL SfxBaseModel::removeModify
 
 void SAL_CALL SfxBaseModel::close( sal_Bool bDeliverOwnership ) throw (util::CloseVetoException, uno::RuntimeException)
 {
-    static ::rtl::OUString MSG_1 = ::rtl::OUString::createFromAscii("Cant close while saving.");
+    static ::rtl::OUString MSG_1 = ::rtl::OUString::createFromAscii("Can't close while saving.");
 
     ::vos::OGuard aGuard( Application::GetSolarMutex() );
 	if ( impl_isDisposed() || m_pData->m_bClosed || m_pData->m_bClosing )
@@ -2489,7 +2489,7 @@ void SAL_CALL SfxBaseModel::removeDocume
 void SAL_CALL SfxBaseModel::notifyDocumentEvent( const ::rtl::OUString&, const uno::Reference< frame::XController2 >&, const uno::Any& )
     throw ( lang::IllegalArgumentException, lang::NoSupportException, uno::RuntimeException )
 {
-    throw lang::NoSupportException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "SfxBaseModel controlls all the sent notifications itself!" ) ), uno::Reference< uno::XInterface >() );
+    throw lang::NoSupportException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "SfxBaseModel controls all the sent notifications itself!" ) ), uno::Reference< uno::XInterface >() );
 }
 
 //________________________________________________________________________________________________________
@@ -2833,7 +2833,7 @@ void SfxBaseModel::impl_store(  const   
                                 else
                                 {
                                     // if the password is changed a special error should be used in case of shared document
-                                    throw task::ErrorCodeIOException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Cant change password for shared document." ) ), uno::Reference< uno::XInterface >(), ERRCODE_SFX_SHARED_NOPASSWORDCHANGE );
+                                    throw task::ErrorCodeIOException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Can't change password for shared document." ) ), uno::Reference< uno::XInterface >(), ERRCODE_SFX_SHARED_NOPASSWORDCHANGE );
                                 }
                             }
                         }

Modified: openoffice/trunk/main/sfx2/source/notify/eventsupplier.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/notify/eventsupplier.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/notify/eventsupplier.cxx (original)
+++ openoffice/trunk/main/sfx2/source/notify/eventsupplier.cxx Tue Apr 29 19:25:03 2014
@@ -642,7 +642,7 @@ void SAL_CALL SfxGlobalEvents_Impl::noti
         const css::uno::Reference< css::frame::XController2 >& /*_ViewController*/, const css::uno::Any& /*_Supplement*/ )
         throw (css::lang::IllegalArgumentException, css::lang::NoSupportException, css::uno::RuntimeException)
 {
-    // we're a multiplexer only, no chance to generate artifical events here
+    // we're a multiplexer only, no chance to generate artificial events here
     throw css::lang::NoSupportException(::rtl::OUString(), *this);
 }
 
@@ -710,7 +710,7 @@ void SAL_CALL SfxGlobalEvents_Impl::inse
     aElement >>= xDoc;
     if (!xDoc.is())
         throw css::lang::IllegalArgumentException(
-                ::rtl::OUString::createFromAscii("Cant locate at least the model parameter."),
+                ::rtl::OUString::createFromAscii("Can't locate at least the model parameter."),
                 static_cast< css::container::XSet* >(this),
                 0);
 
@@ -747,7 +747,7 @@ void SAL_CALL SfxGlobalEvents_Impl::remo
     aElement >>= xDoc;
     if (!xDoc.is())
         throw css::lang::IllegalArgumentException(
-                ::rtl::OUString::createFromAscii("Cant locate at least the model parameter."),
+                ::rtl::OUString::createFromAscii("Can't locate at least the model parameter."),
                 static_cast< css::container::XSet* >(this),
                 0);
 

Modified: openoffice/trunk/main/sfx2/source/view/frmload.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/view/frmload.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/view/frmload.cxx (original)
+++ openoffice/trunk/main/sfx2/source/view/frmload.cxx Tue Apr 29 19:25:03 2014
@@ -234,7 +234,7 @@ namespace
             return sal_False;
 
         // default must be set to true, because some return values
-        // cant be checked, but nonetheless indicate "success"!
+        // can't be checked, but nonetheless indicate "success"!
 	    sal_Bool bSuccess = sal_True;
 
 	    // On the other side some special slots return a boolean state,
@@ -530,7 +530,7 @@ sal_Bool SAL_CALL SfxFrameLoader_Impl::l
     if ( !aDescriptor.has( "Referer" ) )
         aDescriptor.put( "Referer", ::rtl::OUString() );
 
-    // TODO: is this needed? finally, when loading is successfull, then there should be no need for this item,
+    // TODO: is this needed? finally, when loading is successful, then there should be no need for this item,
     // as the document can always obtain its frame. In particular, there might be situations where this frame
     // is accessed, but already disposed: Imagine the user loading a document, opening a second view on it, and
     // then closing the first view/frame.

Modified: openoffice/trunk/main/sfx2/source/view/ipclient.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/view/ipclient.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/view/ipclient.cxx (original)
+++ openoffice/trunk/main/sfx2/source/view/ipclient.cxx Tue Apr 29 19:25:03 2014
@@ -247,7 +247,7 @@ void SAL_CALL SfxInPlaceClient_Impl::sav
         // and the user didn't request saving the changes
         return;
 
-	// the common persistance is supported by objects and links
+	// the common persistence is supported by objects and links
 	uno::Reference< embed::XCommonEmbedPersist > xPersist( m_xObject, uno::UNO_QUERY );
 	if ( !xPersist.is() )
 		throw uno::RuntimeException();

Modified: openoffice/trunk/main/sfx2/source/view/sfxbasecontroller.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/view/sfxbasecontroller.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/view/sfxbasecontroller.cxx (original)
+++ openoffice/trunk/main/sfx2/source/view/sfxbasecontroller.cxx Tue Apr 29 19:25:03 2014
@@ -668,7 +668,7 @@ sal_Bool SAL_CALL SfxBaseController::sus
 {
 	::vos::OGuard aGuard( Application::GetSolarMutex() );
 
-	// ignore dublicate calls, which doesnt change anything real
+	// ignore dublicate calls, which doesn't change anything real
 	if (bSuspend == m_pData->m_bSuspendState)
 	   return sal_True;
 
@@ -1419,7 +1419,7 @@ void SfxBaseController::ConnectSfxFrame_
             if ( !bHasPluginMode && !bHasJumpMark )
             {
                 // Note that this might not be the ideal place here. Restoring view data should, IMO, be the
-                // responsibility of the loader, not an implementation detail burried here deep within the controller's
+                // responsibility of the loader, not an implementation detail buried here deep within the controller's
                 // implementation.
                 // What I think should be done to replace the below code:
                 // - change SfxBaseController::restoreViewData to also accept a PropertyValue[] (it currently accepts

Modified: openoffice/trunk/main/sfx2/source/view/viewprn.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/view/viewprn.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/view/viewprn.cxx (original)
+++ openoffice/trunk/main/sfx2/source/view/viewprn.cxx Tue Apr 29 19:25:03 2014
@@ -334,7 +334,7 @@ void SfxPrinterController::jobFinished( 
 			}
 			case view::PrintableState_JOB_ABORTED :
 			{
-				// printing not succesful, reset DocInfo
+				// printing not successful, reset DocInfo
 				uno::Reference<document::XDocumentProperties> xDocProps(mpObjectShell->getDocProperties());
 				xDocProps->setPrintedBy(m_aLastPrintedBy);
 				xDocProps->setPrintDate(m_aLastPrinted);

Modified: openoffice/trunk/main/sfx2/source/view/viewsh.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/view/viewsh.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/view/viewsh.cxx (original)
+++ openoffice/trunk/main/sfx2/source/view/viewsh.cxx Tue Apr 29 19:25:03 2014
@@ -213,7 +213,7 @@ throw ( uno::RuntimeException )
         xNotify->removeClipboardListener( xThis );
 
     // Make asynchronous call to avoid locking SolarMutex which is the
-    // root for many deadlocks, especially in conjuction with the "Windows"
+    // root for many deadlocks, especially in conjunction with the "Windows"
     // based single thread apartment clipboard code!
     AsyncExecuteInfo* pInfo = new AsyncExecuteInfo( ASYNCEXECUTE_CMD_DISPOSING, xThis, this );
     Application::PostUserEvent( STATIC_LINK( 0, SfxClipboardChangeListener, AsyncExecuteHdl_Impl ), pInfo );
@@ -223,7 +223,7 @@ void SAL_CALL SfxClipboardChangeListener
         throw ( RuntimeException )
 {
     // Make asynchronous call to avoid locking SolarMutex which is the
-    // root for many deadlocks, especially in conjuction with the "Windows"
+    // root for many deadlocks, especially in conjunction with the "Windows"
     // based single thread apartment clipboard code!
     uno::Reference< datatransfer::clipboard::XClipboardListener > xThis( static_cast< datatransfer::clipboard::XClipboardListener* >( this ));
     AsyncExecuteInfo* pInfo = new AsyncExecuteInfo( ASYNCEXECUTE_CMD_CHANGEDCONTENTS, xThis, this );

Modified: openoffice/trunk/main/shell/inc/internal/xml_parser.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/shell/inc/internal/xml_parser.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/shell/inc/internal/xml_parser.hxx (original)
+++ openoffice/trunk/main/shell/inc/internal/xml_parser.hxx Tue Apr 29 19:25:03 2014
@@ -79,7 +79,7 @@ public:
 		@param		IsFinal
 					Indicates whether these are the last xml data
 					of an xml document to parse. For very large 
-					xml documents it may be usefull to read and 
+					xml documents it may be useful to read and 
 					parse the document partially.
 
 		@precond	XmlData must not be null

Modified: openoffice/trunk/main/shell/qa/zip/ziptest.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/shell/qa/zip/ziptest.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/shell/qa/zip/ziptest.cxx (original)
+++ openoffice/trunk/main/shell/qa/zip/ziptest.cxx Tue Apr 29 19:25:03 2014
@@ -77,7 +77,7 @@ void Test::test_getContent()
 {
 		TestZipImpl testImpl(documentName.c_str());
 		bool isPassed = testImpl.test_getContent();
-		CPPUNIT_ASSERT_MESSAGE("Couldn't recieve content buffer form zipfile.", isPassed);
+		CPPUNIT_ASSERT_MESSAGE("Couldn't receive content buffer form zipfile.", isPassed);
 }
 
 //#####################################

Modified: openoffice/trunk/main/shell/source/all/ooofilereader/metainforeader.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/shell/source/all/ooofilereader/metainforeader.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/shell/source/all/ooofilereader/metainforeader.cxx (original)
+++ openoffice/trunk/main/shell/source/all/ooofilereader/metainforeader.cxx Tue Apr 29 19:25:03 2014
@@ -41,7 +41,7 @@ CBaseReader( DocumentName )
 		m_pSimple_Builder = new CSimpleTag( );
 		m_pDummy_Builder   = new CDummyTag( );
 
-        //retrieve all infomation that is useful
+        //retrieve all information that is useful
         m_AllMetaInfo[META_INFO_AUTHOR]               = EMPTY_XML_TAG;
         m_AllMetaInfo[META_INFO_TITLE]                = EMPTY_XML_TAG;
         m_AllMetaInfo[META_INFO_SUBJECT]              = EMPTY_XML_TAG;
@@ -82,7 +82,7 @@ try
 		m_pSimple_Builder = new CSimpleTag( );
 		m_pDummy_Builder   = new CDummyTag( );
 
-        //retrieve all infomation that is useful
+        //retrieve all information that is useful
         m_AllMetaInfo[META_INFO_AUTHOR]               = EMPTY_XML_TAG;
         m_AllMetaInfo[META_INFO_TITLE]                = EMPTY_XML_TAG;
         m_AllMetaInfo[META_INFO_SUBJECT]              = EMPTY_XML_TAG;
--- openoffice/trunk/main/sd/source/ui/slidesorter/model/SlsPageEnumeration.cxx (original)
+++ openoffice/trunk/main/sd/source/ui/slidesorter/model/SlsPageEnumeration.cxx Tue Apr 29 19:25:03 2014
@@ -54,14 +54,14 @@ private:
 
     /** This constructor sets the internal page index to the given value.
         It does not call AdvanceToNextValidElement() to skip elements that
-        do not fullfill Predicate.
+        do not fulfill Predicate.
     */
     inline PageEnumerationImpl (
         const SlideSorterModel& rModel,
         const PageEnumeration::PagePredicate& rPredicate,
         int nIndex);
 
     /** Skip all elements that do not fullfill Predicate starting with the
         one pointed to by mnIndex.
     */
     inline void AdvanceToNextValidElement (void);
@@ -262,7 +262,7 @@ void PageEnumerationImpl::AdvanceToNextV
     {
         SharedPageDescriptor pDescriptor (mrModel.GetPageDescriptor(mnIndex));
 
-        // Test for the predicate being fullfilled.
+        // Test for the predicate being fulfilled.
         if (pDescriptor.get()!=NULL && maPredicate(pDescriptor))
         {
             // This predicate is valid.
@@ -54,14 +54,14 @@ private:
         int nIndex);
 
-    /** Skip all elements that do not fullfill Predicate starting with the
+    /** Skip all elements that do not fulfill Predicate starting with the
         one pointed to by mnIndex.
     */

Modified: openoffice/trunk/main/sd/source/ui/slidesorter/view/SlsButtonBar.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/slidesorter/view/SlsButtonBar.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/doc/objstor.cxx (original)
+++ openoffice/trunk/main/sfx2/source/doc/objstor.cxx Tue Apr 29 19:25:03 2014
@@ -299,10 +299,10 @@ sal_Bool SfxObjectShell::PutURLContentsT
             uno::Reference< embed::XStorage > xTempStorage =
                 ::comphelper::OStorageHelper::GetStorageFromURL( aTempURL, embed::ElementModes::READWRITE );
 
-            // the password will be transfered from the xStorage to xTempStorage by storage implemetation
+            // the password will be transferred from the xStorage to xTempStorage by storage implemetation
             xStorage->copyToStorage( xTempStorage );
 
             // the temporary storage was commited by the previous method and it will die by refcount
         }
         catch ( uno::Exception& )
         {
@@ -1264,9 +1264,9 @@ sal_Bool SfxObjectShell::SaveTo_Impl
                 // The active storage must be switched. The simple saving is not enough.
                 // The problem is that the target medium contains target MediaDescriptor.
 
-                    // In future the switch of the persistance could be done on stream level:
+                    // In future the switch of the persistence could be done on stream level:
                     // a new wrapper service will be implemented that allows to exchange
-                    // persistance on the fly. So the real persistance will be set
+                    // persistence on the fly. So the real persistence will be set
                     // to that stream only after successful commit of the storage.
                     // TODO/LATER:
                     // create wrapper stream based on the URL
@@ -1275,7 +1275,7 @@ sal_Bool SfxObjectShell::SaveTo_Impl
                     // commit the new storage
                     // call saveCompleted based with this new storage ( get rid of old storage and "frees" URL )
                     // commit the wrapper stream ( the stream will connect the URL only on commit, after that it will hold it )
-                    // if the last step is failed the stream should stay to be transacted and should be commited on any flush
+                    // if the last step is failed the stream should stay to be transacted and should be committed on any flush
                     // so we can forget the stream in any way and the next storage commit will flush it
 
                 AddLog( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX "Save: Own to Own" ) ) );
@@ -1640,7 +1640,7 @@ sal_Bool SfxObjectShell::SaveTo_Impl
                 {
                     pMedium->Close();
 
                     // target medium is still not commited, it should not be closed
                     // commit the package storage and close it, but leave the streams open
                     rMedium.StorageCommit_Impl();
                     rMedium.CloseStorage();
@@ -2025,7 +2025,7 @@ sal_Bool SfxObjectShell::DoSaveObjectAs(
                 }
                 catch( uno::Exception& )
                 {
-                    DBG_ERROR( "The strotage was not commited on DoSaveAs!\n" );
+                    DBG_ERROR( "The strotage was not committed on DoSaveAs!\n" );
                 }
             }
         }
@@ -2949,7 +2949,7 @@ sal_Bool SfxObjectShell::PreDoSaveAs_Imp
         DBG_ERROR("Salvage item present in Itemset, check the parameters!");
 #endif
 
-    // should be unneccessary - too hot to handle!
+    // should be unnecessary - too hot to handle!
     pMergedParams->ClearItem( SID_DOC_SALVAGE );
 
     // take over the new merged itemset
@@ -3537,7 +3537,7 @@ sal_Bool StoragesOfUnknownMediaTypeAreCo
     }
     catch( uno::Exception& )
     {
-        OSL_ENSURE( sal_False, "Cant check storage consistency!\n" );
+        OSL_ENSURE( sal_False, "Can't check storage consistency!\n" );
     }
 
     return sal_True;
@@ -299,10 +299,10 @@ sal_Bool SfxObjectShell::PutURLContentsT
             xStorage->copyToStorage( xTempStorage );
 
-            // the temporary storage was commited by the previous method and it will die by refcount
+            // the temporary storage was committed by the previous method and it will die by refcount
         }
         catch ( uno::Exception& )
@@ -1640,7 +1640,7 @@ sal_Bool SfxObjectShell::SaveTo_Impl
                     pMedium->Close();
 
-                    // target medium is still not commited, it should not be closed
+                    // target medium is still not committed, it should not be closed
                     // commit the package storage and close it, but leave the streams open
                     rMedium.StorageCommit_Impl();

Modified: openoffice/trunk/main/sfx2/source/doc/objuno.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/doc/objuno.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/doc/printhelper.cxx (original)
+++ openoffice/trunk/main/sfx2/source/doc/printhelper.cxx Tue Apr 29 19:25:03 2014
@@ -484,7 +484,7 @@ class ImplUCBPrintWatcher : public ::osl
         SfxPrinter* m_pPrinter;
         /// this describes the target location for the printed temp file
         String m_sTargetURL;
-        /// it holds the temp file alive, till the print job will finish and remove it from disk automaticly if the object die
+        /// it holds the temp file alive, till the print job will finish and remove it from disk automatically if the object die
         ::utl::TempFile* m_pTempFile;
 
     public:
@@ -510,11 +510,11 @@ class ImplUCBPrintWatcher : public ::osl
             }
             /* } SAFE */
 
             // lock for further using of our member isn't neccessary - because
             // we truns alone by defenition. Nobody join for us nor use us ...
             ImplUCBPrintWatcher::moveAndDeleteTemp(&m_pTempFile,m_sTargetURL);
 
-            // finishing of this run() method will call onTerminate() automaticly
+            // finishing of this run() method will call onTerminate() automatically
             // kill this thread there!
         }
 
@@ -526,7 +526,7 @@ class ImplUCBPrintWatcher : public ::osl
         }
 
         /* static helper to move the temp. file to the target location by using the ucb
-           It's static to be useable from outside too. So it's not realy neccessary to start
+           It's static to be useable from outside too. So it's not really necessary to start
            the thread, if finishing of the job was detected outside this thread.
            But it must be called without using a corresponding thread for the given parameter!
          */
@@ -598,7 +598,7 @@ void SAL_CALL SfxPrintHelper::print(cons
     // by executing the slot. Because if it is a ucb relevant URL we must wait for
     // finishing the print job and move the temporary local file by using the ucb
     // to the right location. But in case of no file name is given or it is already
-    // a local one we can supress this special handling. Because then vcl makes all
+    // a local one we can suppress this special handling. Because then vcl makes all
     // right for us.
     String sUcbUrl;
     ::utl::TempFile* pUCBPrintTempFile = NULL;
@@ -635,7 +635,7 @@ void SAL_CALL SfxPrintHelper::print(cons
                 // reasons. Otherwhise we break to much external code ...
                 // We try to convert it to a file URL. If its possible
                 // we put the system path to the item set and let vcl work with it.
                 // No ucb or thread will be neccessary then. In case it couldnt be
                 // converted its not an URL nor a system path. Then we can't accept
                 // this parameter and have to throw an exception.
                 ::rtl::OUString sSystemPath(sTemp);
@@ -670,7 +670,7 @@ void SAL_CALL SfxPrintHelper::print(cons
                 // it's an ucb target. So we must use a temp. file for vcl
                 // and move it after printing by using the ucb.
                 // Create a temp file on the heap (because it must delete the
-                // real file on disk automaticly if it die - bt we have to share it with
+                // real file on disk automatically if it die - bt we have to share it with
                 // some other sources ... e.g. the ImplUCBPrintWatcher).
                 // And we put the name of this temp file to the descriptor instead
                 // of the URL. The URL we save for later using seperatly.
@@ -763,11 +763,11 @@ void SAL_CALL SfxPrintHelper::print(cons
 
     // Ok - may be execution before has finished (or started!) printing.
     // And may it was a printing to a file.
     // Now we have to check if we can move the file (if neccessary) via ucb to his right location.
     // Cases:
     //  a) printing finished                        => move the file directly and forget the watcher thread
     //  b) printing is asynchron and runs currently => start watcher thread and exit this method
     //                                                 This thread make all neccessary things by itself.
     if (pUCBPrintTempFile!=NULL)
     {
         // a)
@@ -778,7 +778,7 @@ void SAL_CALL SfxPrintHelper::print(cons
         else
         {
             // Note: we create(d) some ressource on the heap. (thread and tep file)
-            // They will be delected by the thread automaticly if he finish his run() method.
+            // They will be delected by the thread automatically if he finish his run() method.
             ImplUCBPrintWatcher* pWatcher = new ImplUCBPrintWatcher( pPrinter, pUCBPrintTempFile, sUcbUrl );
             pWatcher->create();
         }
@@ -510,11 +510,11 @@ class ImplUCBPrintWatcher : public ::osl
             /* } SAFE */
 
-            // lock for further using of our member isn't neccessary - because
+            // lock for further using of our member isn't necessary - because
             // we truns alone by defenition. Nobody join for us nor use us ...
             ImplUCBPrintWatcher::moveAndDeleteTemp(&m_pTempFile,m_sTargetURL);
@@ -635,7 +635,7 @@ void SAL_CALL SfxPrintHelper::print(cons
                 // We try to convert it to a file URL. If its possible
                 // we put the system path to the item set and let vcl work with it.
-                // No ucb or thread will be neccessary then. In case it couldnt be
+                // No ucb or thread will be necessary then. In case it couldn't be
                 // converted its not an URL nor a system path. Then we can't accept
                 // this parameter and have to throw an exception.
@@ -763,11 +763,11 @@ void SAL_CALL SfxPrintHelper::print(cons
     // Ok - may be execution before has finished (or started!) printing.
     // And may it was a printing to a file.
-    // Now we have to check if we can move the file (if neccessary) via ucb to his right location.
+    // Now we have to check if we can move the file (if necessary) via ucb to his right location.
     // Cases:
     //  a) printing finished                        => move the file directly and forget the watcher thread
@@ -763,11 +763,11 @@ void SAL_CALL SfxPrintHelper::print(cons
     //  a) printing finished                        => move the file directly and forget the watcher thread
     //  b) printing is asynchron and runs currently => start watcher thread and exit this method
-    //                                                 This thread make all neccessary things by itself.
+    //                                                 This thread make all necessary things by itself.
     if (pUCBPrintTempFile!=NULL)
     {

Modified: openoffice/trunk/main/sfx2/source/doc/sfxbasemodel.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/doc/sfxbasemodel.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================